@@ -114,6 +114,12 @@ class SetCreditScoreCreateContract(Contract):
     pass
 
 
+class LogCreateContract(Contract):
+    full_name = serializers.CharField(max_length=64, allow_null=True)
+    document = serializers.CharField(max_length=64, allow_null=True)
+    address = serializers.CharField(max_length=64, allow_null=True)
+
+
 class RussianProfileID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -144,6 +150,12 @@ class SetCreditScoreID(ID):
     _view_set = 'set_credit_score'
 
 
+class LogID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'log'
+
+
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
@@ -179,3 +191,8 @@ class UserProfileIpExistsPoint(ResponseMixin, CreatePointMixin, ContractPoint):
 class SetCreditScorePoint(CreatePointMixin, ContractPoint):
     _point_id = SetCreditScoreID()
     _create_contract = SetCreditScoreCreateContract
+
+
+class LogPoint(CreatePointMixin, ContractPoint):
+    _point_id = LogID()
+    _create_contract = LogCreateContract
